PER_2015_magn: Visual magnitude observations of Perseids from 2015

PER_2015_magnR Documentation

Visual magnitude observations of Perseids from 2015

Description

Visual magnitude observations of the Perseid shower from 2015.

Format

A list with the same structure as returned by load_vmdb_magnitudes.

Details

PER_2015_magn are magnitude observations loaded with load_vmdb_magnitudes.

See Also

load_vmdb


vismeteor documentation built on May 20, 2026, 1:07 a.m.