Learn R Programming

vismeteor (version 2.0.1)

PER_2015_rates: Visual rate observations of Perseids from 2015

Description

Visual rate observations of the Perseid shower from 2015.

Arguments

Format

A list with the same structure as returned by load_vmdb_rates.

Details

PER_2015_rates are rate observations loaded with load_vmdb_rates.

See Also

load_vmdb