| freq_quantile | R Documentation |
This function generates quantiles with a minimum frequency.
These quantiles are formed from a vector freq of frequencies.
Each quantile then has the minimum total frequency min.
freq_quantile(freq, min)
freq |
integer; A vector of frequencies. |
min |
integer; Minimum total frequency per quantile. |
The frequencies freq are grouped in the order in which they
are passed as a vector.
The minimum min must be greater than 0.
A factor of indices is returned.
The index references the corresponding passed frequency freq.
freq <- c(1, 2, 3, 4, 5, 6, 7, 8, 9)
cumsum(freq)
(f <- freq_quantile(freq, 10))
tapply(freq, f, sum)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.